@@ -1,7 +1,8 @@
 package HTML::FormFu::Element;
 use strict;
 use base 'HTML::FormFu::base';
-use Class::C3;
+use MRO::Compat;
+use mro 'c3';
 
 use HTML::FormFu::Attribute qw(
     mk_attrs
@@ -23,15 +24,13 @@ use HTML::FormFu::ObjectUtil qw(
     get_parent
 );
 use HTML::FormFu::Util qw( require_class xml_escape );
+use Clone ();
 use Scalar::Util qw( refaddr reftype weaken );
-use Storable qw( dclone );
 use Carp qw( croak );
 
 use overload (
-    'eq' => sub { refaddr $_[0] eq refaddr $_[1] },
-    'ne' => sub { refaddr $_[0] ne refaddr $_[1] },
-    '==' => sub { refaddr $_[0] eq refaddr $_[1] },
-    '!=' => sub { refaddr $_[0] ne refaddr $_[1] },
+    'eq' => '_string_equals',
+    '==' => '_object_equals',
     '""' => sub { return shift->render },
     bool => sub {1},
     fallback => 1
@@ -82,29 +81,6 @@ sub new {
     return $self;
 }
 
-sub db {
-    my ( $self, $args ) = @_;
-
-    warn <<'WARNING';
-db() method deprecated and is provided for compatibilty only:
-use model_config() instead as this will be removed
-WARNING
-
-    if ( @_ > 1 ) {
-        if ( !$self->model_config ) {
-            $self->model_config( {} );
-        }
-
-        my $conf = $self->model_config;
-
-        while ( my ( $key, $value ) = each %$args ) {
-            $conf->{$key} = $value;
-        }
-    }
-
-    return $self->model_config;
-}
-
 sub name {
     my ( $self, $name ) = @_;
 
@@ -182,11 +158,11 @@ sub clone {
 
     my %new = %$self;
 
-    $new{tt_args} = dclone $self->{tt_args}
+    $new{tt_args} = Clone::clone $self->{tt_args}
         if $self->{tt_args};
 
-    $new{attributes}   = dclone $self->attributes;
-    $new{model_config} = dclone $self->model_config;
+    $new{attributes}   = Clone::clone $self->attributes;
+    $new{model_config} = Clone::clone $self->model_config;
 
     return bless \%new, ref $self;
 }
@@ -426,7 +402,7 @@ See L<HTML::FormFu/del_attributes_xml> for details.
 
 L</del_attrs_xml> is an alias for L</del_attributes_xml>.
 
-The following methods are shortcuts for accessing L<"/attributes"> keys.
+The following methods are shortcuts for accessing L</attributes> keys.
 
 =head2 id
 
@@ -473,8 +449,8 @@ Return Value: $string
 
 =head2 parent
 
-Returns the L<block element|HTML::FormFu::Element> or L<form|HTML::FormFu> 
-object that this element is attached to.
+Returns the L<block element|HTML::FormFu::Element::Block> or
+L<form|HTML::FormFu> object that this element is attached to.
 
 =head2 get_parent
 
@@ -514,6 +490,8 @@ See L<HTML::FormFu/render_method> for details.
 
 =item L<HTML::FormFu::Element::Checkboxgroup>
 
+=item L<HTML::FormFu::Element::ComboBox>
+
 =item L<HTML::FormFu::Element::ContentButton>
 
 =item L<HTML::FormFu::Element::Date>
@@ -581,18 +559,21 @@ used directly.
 
 =item L<HTML::FormFu::Element::_Input>
 
-=item L<HTML::FormFu::Element::NonBlock>
+=item L<HTML::FormFu::Element::_MultiElement>
+
+=item L<HTML::FormFu::Element::_MultiSelect>
+
+=item L<HTML::FormFu::Element::_MultiText>
+
+=item L<HTML::FormFu::Element::_NonBlock>
 
 =back
 
-=head1 DEPRECATED METHODS
+=head1 REMOVED METHODS
 
 =head2 db
 
-Is deprecated and provided only for backwards compatability. Will be removed
-at some point in the future.
-
-Use L</model_config> instead.
+Has been removed; use L</default_args> instead.
 
 =head1 AUTHOR
 
@@ -602,3 +583,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
